@@ -1,4 +1,4 @@
-from beta9 import env
+from beta9 import Bot, BotContext, BotEventType, BotLocation, env
 from beta9.abstractions import experimental
 from beta9.abstractions.container import Container
 from beta9.abstractions.endpoint import ASGI as asgi
@@ -34,4 +34,9 @@ __all__ = [
     "QueueDepthAutoscaler",
     "experimental",
     "schedule",
+    "integrations",
+    "Bot",
+    "BotContext",
+    "BotEventType",
+    "BotLocation",
 ]
